@@ -9,7 +9,7 @@ from __future__ import absolute_import, print_function, unicode_literals
 from .blkcntnr import BlockItemContainer
 from .enum.style import WD_STYLE_TYPE
 from .oxml.simpletypes import ST_Merge
-from .shared import lazyproperty, Parented
+from .shared import Inches, lazyproperty, Parented
 
 
 class Table(Parented):
@@ -18,16 +18,19 @@ class Table(Parented):
     """
     def __init__(self, tbl, parent):
         super(Table, self).__init__(parent)
-        self._tbl = tbl
+        self._element = self._tbl = tbl
 
-    def add_column(self):
+    def add_column(self, width):
         """
-        Return a |_Column| instance, newly added rightmost to the table.
+        Return a |_Column| object of *width*, newly added rightmost to the
+        table.
         """
         tblGrid = self._tbl.tblGrid
         gridCol = tblGrid.add_gridCol()
+        gridCol.w = width
         for tr in self._tbl.tr_lst:
-            tr.add_tc()
+            tc = tr.add_tc()
+            tc.width = width
         return _Column(gridCol, self)
 
     def add_row(self):
@@ -37,7 +40,8 @@ class Table(Parented):
         tbl = self._tbl
         tr = tbl.add_tr()
         for gridCol in tbl.tblGrid.gridCol_lst:
-            tr.add_tc()
+            tc = tr.add_tc()
+            tc.width = gridCol.w
         return _Row(tr, self)
 
     @property
@@ -141,6 +145,19 @@ class Table(Parented):
         """
         return self
 
+    @property
+    def table_direction(self):
+        """
+        A member of :ref:`WdTableDirection` indicating the direction in which
+        the table cells are ordered, e.g. `WD_TABLE_DIRECTION.LTR`. |None|
+        indicates the value is inherited from the style hierarchy.
+        """
+        return self._element.bidiVisual_val
+
+    @table_direction.setter
+    def table_direction(self, value):
+        self._element.bidiVisual_val = value
+
     @property
     def _cells(self):
         """
@@ -201,9 +218,10 @@ class _Cell(BlockItemContainer):
         added after the table because Word requires a paragraph element as
         the last element in every cell.
         """
-        new_table = super(_Cell, self).add_table(rows, cols)
+        width = self.width if self.width is not None else Inches(1)
+        table = super(_Cell, self).add_table(rows, cols, width)
         self.add_paragraph()
-        return new_table
+        return table
 
     def merge(self, other_cell):
         """
